summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
Diffstat (limited to 'include')
-rw-r--r--include/bootmeth.h2
-rw-r--r--include/extlinux.h (renamed from include/distro.h)10
2 files changed, 6 insertions, 6 deletions
diff --git a/include/bootmeth.h b/include/bootmeth.h
index b12dfd42c90..c3df9702e87 100644
--- a/include/bootmeth.h
+++ b/include/bootmeth.h
@@ -255,7 +255,7 @@ int bootmeth_setup_iter_order(struct bootflow_iter *iter, bool include_global);
* This selects the ordering to use for bootmeths
*
* @order_str: String containing the ordering. This is a comma-separate list of
- * bootmeth-device names, e.g. "syslinux,efi". If empty then a default ordering
+ * bootmeth-device names, e.g. "extlinux,efi". If empty then a default ordering
* is used, based on the sequence number of devices (i.e. using aliases)
* Return: 0 if OK, -ENODEV if an unknown bootmeth is mentioned, -ENOMEM if
* out of memory, -ENOENT if there are no bootmeth devices
diff --git a/include/distro.h b/include/extlinux.h
index 2ee145871b2..721ba46371c 100644
--- a/include/distro.h
+++ b/include/extlinux.h
@@ -4,18 +4,18 @@
* Written by Simon Glass <[email protected]>
*/
-#ifndef __distro_h
-#define __distro_h
+#ifndef __extlinux_h
+#define __extlinux_h
-#define DISTRO_FNAME "extlinux/extlinux.conf"
+#define EXTLINUX_FNAME "extlinux/extlinux.conf"
/**
* struct distro_info - useful information for distro_getfile()
*
* @dev: bootmethod device being used to boot
* @bflow: bootflow being booted
*/
-struct distro_info {
+struct extlinux_info {
struct udevice *dev;
struct bootflow *bflow;
struct cmd_tbl *cmdtp;
@@ -4,18 +4,18 @@
/**
- * struct distro_info - useful information for distro_getfile()
+ * struct extlinux_info - useful information for extlinux_getfile()
*
* @dev: bootmethod device being used to boot